@@ -7,7 +7,7 @@ from django.core.management import call_command
 from nwon_baseline.file_helper import read_file_content
 
 from nwon_django_toolbox.settings import NWON_DJANGO_SETTINGS
-from nwon_django_toolbox.typings import TestFixture
+from nwon_django_toolbox.typings.test_fixture import TestFixture
 
 
 def load_test_fixtures(fixture_files: List[TestFixture]):
