@@ -21,6 +21,7 @@ from nwon_django_toolbox.tests.api_helper import (
     check_put_read_only_field,
     ensure_key_with_object_list,
     ensure_paged_results,
+    test_permissions,
 )
 from nwon_django_toolbox.tests.celery import (
     check_latest_task,
@@ -77,4 +78,5 @@ __all__ = [
     "ApiTest",
     "ensure_paged_results",
     "ensure_key_with_object_list",
+    "test_permissions",
 ]
