@@ -1,15 +1,13 @@
 from typing import Callable, Optional
 
-from django.contrib.auth import get_user_model
+from django.contrib.auth.models import AbstractBaseUser
 from pydantic import BaseModel
 
-User = get_user_model()
-
-LoginFunction = Callable[[User, str], str]
+LoginFunction = Callable[[AbstractBaseUser, str], str]
 
 
 class PermissionTestExpectation(BaseModel):
-    user: User
+    user: AbstractBaseUser
     password: str
     get_list_status_code: Optional[int] = None
     get_list_return_number: Optional[int] = None
